# prob-dists package

Prob-dists is a package which deals with different probability distributions

## Features
Currently, the package supports

	- Gaussian (Normal) Distribution
	- Binomial Distribution
	- Bernoulli Distribution
	- Poisson Distribution

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install prob-dists.

```bash
pip install prob_dists
```

## License
Copyright © 2020 Aditya Vadlamani.\
This is [MIT](https://choosealicense.com/licenses/mit/) licensed.


